@@ -3,5 +3,5 @@ use Object::Simple;
 
 sub title : Attr { default => 1 }
 
-Object::Simple->end;
+Object::Simple->build_class;
 
